summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/test
diff options
context:
space:
mode:
authorLuke Chen <luke.chen@mongodb.com>2022-02-02 15:00:17 +1100
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-02-02 04:51:20 +0000
commit5fea92ae32c7265a957ed760946f75b7c75c0e2e (patch)
treed6fbf3ea747337e0148dca2c1e64f13654a39e5e /src/third_party/wiredtiger/test
parent5f19771466dff7642eacbc2dfe4d4bfb1074b8a4 (diff)
downloadmongo-5fea92ae32c7265a957ed760946f75b7c75c0e2e.tar.gz
Import wiredtiger: 0d65fabfca1e3435e8f8298a98d4fc91c56e331c from branch mongodb-master
ref: 9e92b73891..0d65fabfca for: 5.3.0 WT-7598 Remove autoconf & scons build systems
Diffstat (limited to 'src/third_party/wiredtiger/test')
-rw-r--r--src/third_party/wiredtiger/test/bloom/Makefile.am17
-rw-r--r--src/third_party/wiredtiger/test/checkpoint/Makefile.am15
-rw-r--r--src/third_party/wiredtiger/test/cppsuite/Makefile.am49
-rw-r--r--src/third_party/wiredtiger/test/csuite/Makefile.am175
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/incr_backup/smoke.sh17
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/random_abort/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/random_directio/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/schema_abort/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/tiered_abort/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/time_shift_test.sh10
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/timestamp_abort/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/truncated_log/smoke.sh14
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt2447_join_main_table/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt2535_insert_race/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt2853_perf/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt2909_checkpoint_integrity/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt4105_large_doc_small_upd/smoke.sh12
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt6185_modify_ts/smoke.sh14
-rwxr-xr-xsrc/third_party/wiredtiger/test/csuite/wt6616_checkpoint_oldest_ts/smoke.sh14
-rw-r--r--src/third_party/wiredtiger/test/ctest_helpers.cmake10
-rw-r--r--src/third_party/wiredtiger/test/cursor_order/Makefile.am15
-rwxr-xr-xsrc/third_party/wiredtiger/test/evergreen.yml2
-rwxr-xr-xsrc/third_party/wiredtiger/test/evergreen/evg_cfg.py14
-rw-r--r--src/third_party/wiredtiger/test/fops/Makefile.am18
-rw-r--r--src/third_party/wiredtiger/test/format/Makefile.am31
-rwxr-xr-xsrc/third_party/wiredtiger/test/format/format.sh27
-rw-r--r--src/third_party/wiredtiger/test/fuzz/Makefile.am20
-rw-r--r--src/third_party/wiredtiger/test/fuzz/fuzz_run.sh2
-rw-r--r--src/third_party/wiredtiger/test/huge/Makefile.am16
-rw-r--r--src/third_party/wiredtiger/test/manydbs/Makefile.am17
-rw-r--r--src/third_party/wiredtiger/test/packing/Makefile.am14
-rw-r--r--src/third_party/wiredtiger/test/readonly/Makefile.am16
-rw-r--r--src/third_party/wiredtiger/test/salvage/Makefile.am17
-rwxr-xr-xsrc/third_party/wiredtiger/test/suite/run.py17
-rw-r--r--src/third_party/wiredtiger/test/syscall/Makefile.am7
-rwxr-xr-xsrc/third_party/wiredtiger/test/syscall/syscall.py4
-rw-r--r--src/third_party/wiredtiger/test/thread/Makefile.am15
-rw-r--r--src/third_party/wiredtiger/test/utility/Makefile.am4
-rw-r--r--src/third_party/wiredtiger/test/utility/misc.c41
-rwxr-xr-xsrc/third_party/wiredtiger/test/wtperf/test_conf_dump.py21
40 files changed, 175 insertions, 598 deletions
diff --git a/src/third_party/wiredtiger/test/bloom/Makefile.am b/src/third_party/wiredtiger/test/bloom/Makefile.am
deleted file mode 100644
index 31c585dbb1f..00000000000
--- a/src/third_party/wiredtiger/test/bloom/Makefile.am
+++ /dev/null
@@ -1,17 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = test_bloom.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = $(noinst_PROGRAMS)
-LOG_COMPILER = $(TEST_WRAPPER)
-
-clean-local:
- rm -rf WiredTiger* core.* *.core WT_TEST
diff --git a/src/third_party/wiredtiger/test/checkpoint/Makefile.am b/src/third_party/wiredtiger/test/checkpoint/Makefile.am
deleted file mode 100644
index da7b85ec0b2..00000000000
--- a/src/third_party/wiredtiger/test/checkpoint/Makefile.am
+++ /dev/null
@@ -1,15 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = checkpointer.c workers.c test_checkpoint.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-TESTS = smoke.sh
-
-clean-local:
- rm -rf WT_TEST core.* *.core
diff --git a/src/third_party/wiredtiger/test/cppsuite/Makefile.am b/src/third_party/wiredtiger/test/cppsuite/Makefile.am
deleted file mode 100644
index 31c9e0797a9..00000000000
--- a/src/third_party/wiredtiger/test/cppsuite/Makefile.am
+++ /dev/null
@@ -1,49 +0,0 @@
-AM_CPPFLAGS = -std='c++11' -I$(top_builddir) -I$(top_srcdir)/src/include \
- -I$(top_srcdir)/test/utility -I$(top_srcdir)/test/cppsuite
-LDADD = $(top_builddir)/test/utility/libtest_util.la \
- $(top_builddir)/libwiredtiger.la
-AM_LDFLAGS = -static
-
-# Copy across the default configuration files with the artifacts.
-all:
- rsync -rup $(top_srcdir)/test/cppsuite/configs $(top_builddir)/test/cppsuite
-
-all_TESTS=
-noinst_PROGRAMS=
-
-test_harness = test_harness/core/component.cxx \
- test_harness/core/configuration.cxx \
- test_harness/core/throttle.cxx \
- test_harness/util/api_const.cxx \
- test_harness/util/logger.cxx \
- test_harness/util/scoped_connection.cxx \
- test_harness/util/scoped_types.cxx \
- test_harness/workload/database_model.cxx \
- test_harness/workload/database_operation.cxx \
- test_harness/workload/random_generator.cxx \
- test_harness/workload/thread_context.cxx \
- test_harness/workload/workload_tracking.cxx \
- test_harness/workload/workload_validation.cxx \
- test_harness/checkpoint_manager.cxx \
- test_harness/connection_manager.cxx \
- test_harness/runtime_monitor.cxx \
- test_harness/test.cxx \
- test_harness/thread_manager.cxx \
- test_harness/timestamp_manager.cxx \
- test_harness/workload_generator.cxx
-
-# If you prefer to not use the run binary you can add a test via this
-# mechanism but it is generally frowned upon.
-csuite_style_example_test_SOURCES = $(test_harness) tests/csuite_style_example_test.cxx
-noinst_PROGRAMS += csuite_style_example_test
-all_TESTS += csuite_style_example_test
-
-run_SOURCES = $(test_harness) tests/run.cxx
-noinst_PROGRAMS += run
-all_TESTS += run
-
-# Run this during a "make check" smoke test.
-TESTS = $(all_TESTS)
-
-clean-local:
- rm -rf WT_TEST.* core.* *.core
diff --git a/src/third_party/wiredtiger/test/csuite/Makefile.am b/src/third_party/wiredtiger/test/csuite/Makefile.am
deleted file mode 100644
index 937f58f3255..00000000000
--- a/src/third_party/wiredtiger/test/csuite/Makefile.am
+++ /dev/null
@@ -1,175 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir) -I$(top_srcdir)/src/include \
- -I$(top_srcdir)/test/utility
-LDADD = $(top_builddir)/test/utility/libtest_util.la \
- $(top_builddir)/libwiredtiger.la
-AM_LDFLAGS = -static
-
-all_TESTS=
-noinst_PROGRAMS=
-
-test_incr_backup_SOURCES = incr_backup/main.c
-noinst_PROGRAMS += test_incr_backup
-all_TESTS += incr_backup/smoke.sh
-
-test_random_abort_SOURCES = random_abort/main.c
-noinst_PROGRAMS += test_random_abort
-all_TESTS += random_abort/smoke.sh
-
-test_random_directio_SOURCES = random_directio/main.c random_directio/util.c
-noinst_PROGRAMS += test_random_directio
-all_TESTS += random_directio/smoke.sh
-
-test_rwlock_SOURCES = rwlock/main.c
-noinst_PROGRAMS += test_rwlock
-all_TESTS += test_rwlock
-
-test_schema_abort_SOURCES = schema_abort/main.c
-noinst_PROGRAMS += test_schema_abort
-all_TESTS += schema_abort/smoke.sh
-
-test_scope_SOURCES = scope/main.c
-noinst_PROGRAMS += test_scope
-all_TESTS += test_scope
-
-test_tiered_abort_SOURCES = tiered_abort/main.c
-noinst_PROGRAMS += test_tiered_abort
-all_TESTS += tiered_abort/smoke.sh
-
-test_timestamp_abort_SOURCES = timestamp_abort/main.c
-noinst_PROGRAMS += test_timestamp_abort
-all_TESTS += timestamp_abort/smoke.sh
-
-test_truncated_log_SOURCES = truncated_log/main.c
-noinst_PROGRAMS += test_truncated_log
-all_TESTS += truncated_log/smoke.sh
-
-test_wt1965_col_efficiency_SOURCES = wt1965_col_efficiency/main.c
-noinst_PROGRAMS += test_wt1965_col_efficiency
-all_TESTS += test_wt1965_col_efficiency
-
-test_wt2403_lsm_workload_SOURCES = wt2403_lsm_workload/main.c
-noinst_PROGRAMS += test_wt2403_lsm_workload
-all_TESTS += test_wt2403_lsm_workload
-
-test_wt2246_col_append_SOURCES = wt2246_col_append/main.c
-noinst_PROGRAMS += test_wt2246_col_append
-all_TESTS += test_wt2246_col_append
-
-test_wt2323_join_visibility_SOURCES = wt2323_join_visibility/main.c
-noinst_PROGRAMS += test_wt2323_join_visibility
-all_TESTS += test_wt2323_join_visibility
-
-test_wt2535_insert_race_SOURCES = wt2535_insert_race/main.c
-noinst_PROGRAMS += test_wt2535_insert_race
-all_TESTS += wt2535_insert_race/smoke.sh
-
-test_wt2447_join_main_table_SOURCES = wt2447_join_main_table/main.c
-noinst_PROGRAMS += test_wt2447_join_main_table
-all_TESTS += wt2447_join_main_table/smoke.sh
-
-test_wt2695_checksum_SOURCES = wt2695_checksum/main.c
-noinst_PROGRAMS += test_wt2695_checksum
-all_TESTS += test_wt2695_checksum
-
-test_wt2592_join_schema_SOURCES = wt2592_join_schema/main.c
-noinst_PROGRAMS += test_wt2592_join_schema
-all_TESTS += test_wt2592_join_schema
-
-test_wt2719_reconfig_SOURCES = wt2719_reconfig/main.c
-noinst_PROGRAMS += test_wt2719_reconfig
-all_TESTS += test_wt2719_reconfig
-
-test_wt2834_join_bloom_fix_SOURCES = wt2834_join_bloom_fix/main.c
-noinst_PROGRAMS += test_wt2834_join_bloom_fix
-all_TESTS += test_wt2834_join_bloom_fix
-
-test_wt2853_perf_SOURCES = wt2853_perf/main.c
-noinst_PROGRAMS += test_wt2853_perf
-all_TESTS += wt2853_perf/smoke.sh
-
-test_wt2909_checkpoint_integrity_SOURCES = wt2909_checkpoint_integrity/main.c
-noinst_PROGRAMS += test_wt2909_checkpoint_integrity
-all_TESTS += wt2909_checkpoint_integrity/smoke.sh
-
-test_wt2999_join_extractor_SOURCES = wt2999_join_extractor/main.c
-noinst_PROGRAMS += test_wt2999_join_extractor
-all_TESTS += test_wt2999_join_extractor
-
-test_wt3120_filesys_SOURCES = wt3120_filesys/main.c
-noinst_PROGRAMS += test_wt3120_filesys
-all_TESTS += test_wt3120_filesys
-
-test_wt3135_search_near_collator_SOURCES = wt3135_search_near_collator/main.c
-noinst_PROGRAMS += test_wt3135_search_near_collator
-all_TESTS += test_wt3135_search_near_collator
-
-test_wt3184_dup_index_collator_SOURCES = wt3184_dup_index_collator/main.c
-noinst_PROGRAMS += test_wt3184_dup_index_collator
-all_TESTS += test_wt3184_dup_index_collator
-
-test_wt3338_partial_update_SOURCES = wt3338_partial_update/main.c
-noinst_PROGRAMS += test_wt3338_partial_update
-all_TESTS += test_wt3338_partial_update
-
-test_wt3363_checkpoint_op_races_SOURCES = wt3363_checkpoint_op_races/main.c
-noinst_PROGRAMS += test_wt3363_checkpoint_op_races
-all_TESTS += test_wt3363_checkpoint_op_races
-
-test_wt3874_pad_byte_collator_SOURCES = wt3874_pad_byte_collator/main.c
-noinst_PROGRAMS += test_wt3874_pad_byte_collator
-all_TESTS += test_wt3874_pad_byte_collator
-
-test_wt4105_large_doc_small_upd_SOURCES = wt4105_large_doc_small_upd/main.c
-noinst_PROGRAMS += test_wt4105_large_doc_small_upd
-all_TESTS += wt4105_large_doc_small_upd/smoke.sh
-
-test_wt4117_checksum_SOURCES = wt4117_checksum/main.c
-noinst_PROGRAMS += test_wt4117_checksum
-all_TESTS += test_wt4117_checksum
-
-test_wt4156_metadata_salvage_SOURCES = wt4156_metadata_salvage/main.c
-noinst_PROGRAMS += test_wt4156_metadata_salvage
-all_TESTS += test_wt4156_metadata_salvage
-
-test_wt4333_handle_locks_SOURCES = wt4333_handle_locks/main.c
-noinst_PROGRAMS += test_wt4333_handle_locks
-all_TESTS += test_wt4333_handle_locks
-
-test_wt4699_json_SOURCES = wt4699_json/main.c
-noinst_PROGRAMS += test_wt4699_json
-all_TESTS += test_wt4699_json
-
-test_wt4803_history_store_abort_SOURCES = wt4803_history_store_abort/main.c
-noinst_PROGRAMS += test_wt4803_history_store_abort
-all_TESTS += test_wt4803_history_store_abort
-
-test_wt4891_meta_ckptlist_get_alloc_SOURCES=wt4891_meta_ckptlist_get_alloc/main.c
-noinst_PROGRAMS += test_wt4891_meta_ckptlist_get_alloc
-all_TESTS += test_wt4891_meta_ckptlist_get_alloc
-
-test_wt6185_modify_ts_SOURCES = wt6185_modify_ts/main.c
-noinst_PROGRAMS += test_wt6185_modify_ts
-all_TESTS += wt6185_modify_ts/smoke.sh
-
-test_wt6616_checkpoint_oldest_ts_SOURCES = wt6616_checkpoint_oldest_ts/main.c
-noinst_PROGRAMS += test_wt6616_checkpoint_oldest_ts
-all_TESTS += wt6616_checkpoint_oldest_ts/smoke.sh
-
-test_wt7989_compact_checkpoint_SOURCES = wt7989_compact_checkpoint/main.c
-noinst_PROGRAMS += test_wt7989_compact_checkpoint
-all_TESTS += test_wt7989_compact_checkpoint
-
-test_wt8057_compact_stress_SOURCES = wt8057_compact_stress/main.c
-noinst_PROGRAMS += test_wt8057_compact_stress
-all_TESTS += test_wt8057_compact_stress
-
-test_wt8246_compact_rts_data_correctness_SOURCES = wt8246_compact_rts_data_correctness/main.c
-noinst_PROGRAMS += test_wt8246_compact_rts_data_correctness
-all_TESTS += test_wt8246_compact_rts_data_correctness
-
-# Run this during a "make check" smoke test.
-TESTS = $(all_TESTS)
-LOG_COMPILER = env top_builddir=$(top_builddir) top_srcdir=$(top_srcdir) $(TEST_WRAPPER)
-
-clean-local:
- rm -rf WT_TEST.* core.* *.core
diff --git a/src/third_party/wiredtiger/test/csuite/incr_backup/smoke.sh b/src/third_party/wiredtiger/test/csuite/incr_backup/smoke.sh
index 7816a4ec70b..a465761b021 100755
--- a/src/third_party/wiredtiger/test/csuite/incr_backup/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/incr_backup/smoke.sh
@@ -7,12 +7,15 @@ set -e
if [ -n "$1" ]
then
# If the test binary is passed in manually.
- $TEST_WRAPPER $1 -v 3
+ test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
-
- $TEST_WRAPPER $top_builddir/test/csuite/test_incr_backup -v 3
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_incr_backup
fi
+
+$TEST_WRAPPER $test_bin -v 3
diff --git a/src/third_party/wiredtiger/test/csuite/random_abort/smoke.sh b/src/third_party/wiredtiger/test/csuite/random_abort/smoke.sh
index bfa8656f6b1..aa3a629bd70 100755
--- a/src/third_party/wiredtiger/test/csuite/random_abort/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/random_abort/smoke.sh
@@ -9,11 +9,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_random_abort
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_random_abort
fi
$TEST_WRAPPER $test_bin -t 10 -T 5
$TEST_WRAPPER $test_bin -m -t 10 -T 5
diff --git a/src/third_party/wiredtiger/test/csuite/random_directio/smoke.sh b/src/third_party/wiredtiger/test/csuite/random_directio/smoke.sh
index 9c7c043beb0..f8420b77ae4 100755
--- a/src/third_party/wiredtiger/test/csuite/random_directio/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/random_directio/smoke.sh
@@ -4,16 +4,18 @@ set -e
# Smoke-test random_directio as part of running "make check".
-# If $top_builddir/$top_srcdir aren't set, default to building in build_posix
-# and running in test/csuite.
-top_builddir=${top_builddir:-../../build_posix}
-top_srcdir=${top_srcdir:-../..}
+# If $binary_dir isn't set, default to using the build directory
+# this script resides under. Our CMake build will sync a copy of this
+# script to the build directory. Note this assumes we are executing a
+# copy of the script that lives under the build directory. Otherwise
+# passing the binary path is required.
+binary_dir=${binary_dir:-`dirname $0`}
if [ -n "$1" ]
then
RUN_TEST_CMD="$TEST_WRAPPER $1"
else
- RUN_TEST_CMD="$TEST_WRAPPER $top_builddir/test/csuite/test_random_directio"
+ RUN_TEST_CMD="$TEST_WRAPPER $binary_dir/test_random_directio"
fi
# Replace for more complete testing
#TEST_THREADS="1 5 10"
diff --git a/src/third_party/wiredtiger/test/csuite/schema_abort/smoke.sh b/src/third_party/wiredtiger/test/csuite/schema_abort/smoke.sh
index bed880271d6..84702d5111e 100755
--- a/src/third_party/wiredtiger/test/csuite/schema_abort/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/schema_abort/smoke.sh
@@ -10,11 +10,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_schema_abort
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_schema_abort
fi
$TEST_WRAPPER $test_bin -t 10 -T 5
diff --git a/src/third_party/wiredtiger/test/csuite/tiered_abort/smoke.sh b/src/third_party/wiredtiger/test/csuite/tiered_abort/smoke.sh
index 98431781c2f..3faeff5217f 100755
--- a/src/third_party/wiredtiger/test/csuite/tiered_abort/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/tiered_abort/smoke.sh
@@ -12,10 +12,12 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_tiered_abort
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_tiered_abort
fi
$TEST_WRAPPER $test_bin -t 10 -T 5
diff --git a/src/third_party/wiredtiger/test/csuite/time_shift_test.sh b/src/third_party/wiredtiger/test/csuite/time_shift_test.sh
index 6d92afe426a..3c32abde67f 100755
--- a/src/third_party/wiredtiger/test/csuite/time_shift_test.sh
+++ b/src/third_party/wiredtiger/test/csuite/time_shift_test.sh
@@ -43,7 +43,15 @@ then
fi
# Locate Wiredtiger home directory.
-: ${RW_LOCK_FILE:=$(git rev-parse --show-toplevel)/build_posix/test/csuite/test_rwlock}
+# If RW_LOCK_FILE isn't set, default to using the build directory this script resides under
+# under. Our CMake build will sync a copy of this script to the build directory the 'test_rwlock'
+# binary is created under. Note this assumes we are executing a copy of the script that lives under
+# the build directory. Otherwise passing the binary path is required.
+: ${RW_LOCK_FILE:=$(dirname $0)/test_rwlock}
+[ -x ${RW_LOCK_FILE} ] || {
+ echo "fail: unable to locate rwlock test binary"
+ exit 1
+}
SEC1=`date +%s`
if [ "$RUN_OS" = "Darwin" ]
diff --git a/src/third_party/wiredtiger/test/csuite/timestamp_abort/smoke.sh b/src/third_party/wiredtiger/test/csuite/timestamp_abort/smoke.sh
index b2c70340f4c..ac77db804a6 100755
--- a/src/third_party/wiredtiger/test/csuite/timestamp_abort/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/timestamp_abort/smoke.sh
@@ -15,11 +15,13 @@ done
if [ -z "$test_bin" ]
then
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_timestamp_abort
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_timestamp_abort
fi
$TEST_WRAPPER $test_bin $default_test_args
diff --git a/src/third_party/wiredtiger/test/csuite/truncated_log/smoke.sh b/src/third_party/wiredtiger/test/csuite/truncated_log/smoke.sh
index 0079adf0340..fd17597768b 100755
--- a/src/third_party/wiredtiger/test/csuite/truncated_log/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/truncated_log/smoke.sh
@@ -9,12 +9,14 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_truncated_log
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_truncated_log
fi
-$TEST_WRAPPER $test_bin
+$TEST_WRAPPER $test_bin
$TEST_WRAPPER $test_bin -c
diff --git a/src/third_party/wiredtiger/test/csuite/wt2447_join_main_table/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt2447_join_main_table/smoke.sh
index c57694807ac..4aecdc7ebda 100755
--- a/src/third_party/wiredtiger/test/csuite/wt2447_join_main_table/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt2447_join_main_table/smoke.sh
@@ -9,11 +9,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt2447_join_main_table
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt2447_join_main_table
fi
$TEST_WRAPPER $test_bin -t r
diff --git a/src/third_party/wiredtiger/test/csuite/wt2535_insert_race/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt2535_insert_race/smoke.sh
index 9db537df92b..914fceaa1cb 100755
--- a/src/third_party/wiredtiger/test/csuite/wt2535_insert_race/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt2535_insert_race/smoke.sh
@@ -9,11 +9,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt2535_insert_race
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt2535_insert_race
fi
$TEST_WRAPPER $test_bin -t r
diff --git a/src/third_party/wiredtiger/test/csuite/wt2853_perf/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt2853_perf/smoke.sh
index d2351082329..6dcc4497d14 100755
--- a/src/third_party/wiredtiger/test/csuite/wt2853_perf/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt2853_perf/smoke.sh
@@ -9,11 +9,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt2853_perf
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt2853_perf
fi
$TEST_WRAPPER $test_bin -t r
diff --git a/src/third_party/wiredtiger/test/csuite/wt2909_checkpoint_integrity/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt2909_checkpoint_integrity/smoke.sh
index e7c8f15f5a6..23b66d19864 100755
--- a/src/third_party/wiredtiger/test/csuite/wt2909_checkpoint_integrity/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt2909_checkpoint_integrity/smoke.sh
@@ -18,11 +18,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt2909_checkpoint_integrity
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt2909_checkpoint_integrity
fi
$TEST_WRAPPER $test_bin $builddir_arg -t r
diff --git a/src/third_party/wiredtiger/test/csuite/wt4105_large_doc_small_upd/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt4105_large_doc_small_upd/smoke.sh
index e8cfe61081f..fadd4559151 100755
--- a/src/third_party/wiredtiger/test/csuite/wt4105_large_doc_small_upd/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt4105_large_doc_small_upd/smoke.sh
@@ -9,11 +9,13 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt4105_large_doc_small_upd
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt4105_large_doc_small_upd
fi
$TEST_WRAPPER $test_bin -t r
diff --git a/src/third_party/wiredtiger/test/csuite/wt6185_modify_ts/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt6185_modify_ts/smoke.sh
index b317eeeb2ed..92b540ba3b4 100755
--- a/src/third_party/wiredtiger/test/csuite/wt6185_modify_ts/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt6185_modify_ts/smoke.sh
@@ -9,13 +9,15 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt6185_modify_ts
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt6185_modify_ts
fi
-$TEST_WRAPPER $test_bin
+$TEST_WRAPPER $test_bin
$TEST_WRAPPER $test_bin -C
diff --git a/src/third_party/wiredtiger/test/csuite/wt6616_checkpoint_oldest_ts/smoke.sh b/src/third_party/wiredtiger/test/csuite/wt6616_checkpoint_oldest_ts/smoke.sh
index 9b9cc997026..85743e0abbd 100755
--- a/src/third_party/wiredtiger/test/csuite/wt6616_checkpoint_oldest_ts/smoke.sh
+++ b/src/third_party/wiredtiger/test/csuite/wt6616_checkpoint_oldest_ts/smoke.sh
@@ -9,13 +9,15 @@ then
# If the test binary is passed in manually.
test_bin=$1
else
- # If $top_builddir/$top_srcdir aren't set, default to building in build_posix
- # and running in test/csuite.
- top_builddir=${top_builddir:-../../build_posix}
- top_srcdir=${top_srcdir:-../..}
- test_bin=$top_builddir/test/csuite/test_wt6616_checkpoint_oldest_ts
+ # If $binary_dir isn't set, default to using the build directory
+ # this script resides under. Our CMake build will sync a copy of this
+ # script to the build directory. Note this assumes we are executing a
+ # copy of the script that lives under the build directory. Otherwise
+ # passing the binary path is required.
+ binary_dir=${binary_dir:-`dirname $0`}
+ test_bin=$binary_dir/test_wt6616_checkpoint_oldest_ts
fi
-$TEST_WRAPPER $test_bin
+$TEST_WRAPPER $test_bin
$TEST_WRAPPER $test_bin -c
diff --git a/src/third_party/wiredtiger/test/ctest_helpers.cmake b/src/third_party/wiredtiger/test/ctest_helpers.cmake
index 23b00f9305e..65ca76d6404 100644
--- a/src/third_party/wiredtiger/test/ctest_helpers.cmake
+++ b/src/third_party/wiredtiger/test/ctest_helpers.cmake
@@ -190,7 +190,7 @@ function(define_c_test)
"C_TEST"
""
"TARGET;DIR_NAME;DEPENDS;EXEC_SCRIPT"
- "SOURCES;FLAGS;ARGUMENTS;VARIANTS"
+ "SOURCES;FLAGS;ARGUMENTS;VARIANTS;ADDITIONAL_FILES"
)
if (NOT "${C_TEST_UNPARSED_ARGUMENTS}" STREQUAL "")
message(FATAL_ERROR "Unknown arguments to define_c_test: ${C_TEST_UNPARSED_ARGUMENTS}")
@@ -213,9 +213,13 @@ function(define_c_test)
eval_dependency("${C_TEST_DEPENDS}" enabled)
if(enabled)
set(additional_executable_args)
+ set(additional_file_args)
if(NOT "${C_TEST_FLAGS}" STREQUAL "")
list(APPEND additional_executable_args FLAGS ${C_TEST_FLAGS})
endif()
+ if(NOT "${C_TEST_ADDITIONAL_FILES}" STREQUAL "")
+ list(APPEND additional_file_args ${C_TEST_ADDITIONAL_FILES})
+ endif()
set(exec_wrapper)
if(WT_WIN)
# This is a workaround to run our csuite tests under Windows using CTest. When executing a test,
@@ -225,10 +229,11 @@ function(define_c_test)
endif()
set(test_cmd)
if (C_TEST_EXEC_SCRIPT)
+ list(APPEND additional_file_args ${C_TEST_EXEC_SCRIPT})
# Define the c test to be executed with a script, rather than invoking the binary directly.
create_test_executable(${C_TEST_TARGET}
SOURCES ${C_TEST_SOURCES}
- ADDITIONAL_FILES ${C_TEST_EXEC_SCRIPT}
+ ADDITIONAL_FILES ${additional_file_args}
BINARY_DIR ${CMAKE_CURRENT_BINARY_DIR}/${C_TEST_DIR_NAME}
${additional_executable_args}
)
@@ -237,6 +242,7 @@ function(define_c_test)
else()
create_test_executable(${C_TEST_TARGET}
SOURCES ${C_TEST_SOURCES}
+ ADDITIONAL_FILES ${additional_file_args}
BINARY_DIR ${CMAKE_CURRENT_BINARY_DIR}/${C_TEST_DIR_NAME}
${additional_executable_args}
)
diff --git a/src/third_party/wiredtiger/test/cursor_order/Makefile.am b/src/third_party/wiredtiger/test/cursor_order/Makefile.am
deleted file mode 100644
index 448f8f95772..00000000000
--- a/src/third_party/wiredtiger/test/cursor_order/Makefile.am
+++ /dev/null
@@ -1,15 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = cursor_order
-cursor_order_SOURCES = cursor_order_file.c cursor_order_ops.c cursor_order.c
-
-cursor_order_LDADD = $(top_builddir)/test/utility/libtest_util.la
-cursor_order_LDADD +=$(top_builddir)/libwiredtiger.la
-cursor_order_LDFLAGS = -static
-
-TESTS = smoke.sh
-
-clean-local:
- rm -rf WT_TEST core.* *.core
diff --git a/src/third_party/wiredtiger/test/evergreen.yml b/src/third_party/wiredtiger/test/evergreen.yml
index dd8464ac049..99488cbfd5b 100755
--- a/src/third_party/wiredtiger/test/evergreen.yml
+++ b/src/third_party/wiredtiger/test/evergreen.yml
@@ -1694,7 +1694,7 @@ tasks:
set -o errexit
set -o verbose
- ${test_env_vars|} WTPERF_DIR=$(pwd) ${python_binary|python3} ../../../test/wtperf/test_conf_dump.py 2>&1
+ ${test_env_vars|} ${python_binary|python3} ../../../test/wtperf/test_conf_dump.py -d $(pwd) 2>&1
- name: fops
tags: ["pull_request"]
diff --git a/src/third_party/wiredtiger/test/fops/Makefile.am b/src/third_party/wiredtiger/test/fops/Makefile.am
deleted file mode 100644
index 519f6315445..00000000000
--- a/src/third_party/wiredtiger/test/fops/Makefile.am
+++ /dev/null
@@ -1,18 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-
-t_SOURCES = thread.h file.c fops.c t.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = $(noinst_PROGRAMS)
-LOG_COMPILER = $(TEST_WRAPPER)
-
-clean-local:
- rm -rf WT_TEST core.* *.core
diff --git a/src/third_party/wiredtiger/test/format/Makefile.am b/src/third_party/wiredtiger/test/format/Makefile.am
deleted file mode 100644
index 8897feee112..00000000000
--- a/src/third_party/wiredtiger/test/format/Makefile.am
+++ /dev/null
@@ -1,31 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES =\
- alter.c backup.c bulk.c checkpoint.c compact.c config.c config_compat.c config_def.c hs.c \
- import.c kv.c ops.c random.c salvage.c snap.c t.c trace.c util.c wts.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-#noinst_LTLIBRARIES = lzo_compress.la
-
-# libtool hack: noinst_LTLIBRARIES turns off building shared libraries as well
-# as installation, it will only build static libraries. As far as I can tell,
-# the "approved" libtool way to turn them back on is by adding -rpath.
-#lzo_compress_la_SOURCES = lzo_compress.c
-#lzo_compress_la_LIBADD = -llzo2 -lm
-#lzo_compress_la_LDFLAGS = -avoid-version -module -rpath /nowhere
-
-backup:
- rm -rf BACKUP && cp -p -r RUNDIR BACKUP
-refresh:
- rm -rf RUNDIR && cp -p -r BACKUP RUNDIR
-
-TESTS = smoke.sh
-
-clean-local:
- rm -rf RUNDIR s_dumpcmp core.* *.core
diff --git a/src/third_party/wiredtiger/test/format/format.sh b/src/third_party/wiredtiger/test/format/format.sh
index 5c8331935ba..f13a1883ab8 100755
--- a/src/third_party/wiredtiger/test/format/format.sh
+++ b/src/third_party/wiredtiger/test/format/format.sh
@@ -44,6 +44,7 @@ usage() {
echo " -a configure format abort/recovery testing (defaults to off)"
echo " -b binary format binary (defaults to "./t")"
echo " -c config format configuration file (defaults to CONFIG.stress)"
+ echo " -d directory directory of format binary"
echo " -D directory directory of format configuration files (named \"CONFIG.*\")"
echo " -E skip known errors (defaults to off)"
echo " -e envvar Environment variable setting (default to none)"
@@ -107,6 +108,8 @@ quit=0
skip_errors=0
stress_split_test=0
total_jobs=0
+# Default to format.sh directory (assumed to be in a WiredTiger build tree).
+format_bin_dir=`dirname $0`
while :; do
case "$1" in
@@ -119,6 +122,9 @@ while :; do
-c)
config="$2"
shift ; shift ;;
+ -d)
+ format_bin_dir="$2"
+ shift ; shift ;;
-D)
# Format changes directories, get absolute paths to the CONFIG files.
dir="$2"
@@ -222,7 +228,7 @@ config_found=0
}
# Move to the format.sh directory (assumed to be in a WiredTiger build tree).
-cd $(dirname $0) || exit 1
+cd $format_bin_dir || exit 1
# If we haven't already found it, check for the config file (by default it's CONFIG.stress which
# lives in the same directory of the WiredTiger build tree as format.sh. We're about to change
@@ -233,17 +239,14 @@ cd $(dirname $0) || exit 1
config_found=1
}
-# Find the last part of format_binary, which is format binary file. Builds are normally in the
-# WiredTiger source tree, in which case it's in the same directory as format.sh, else it's in
-# the build_posix tree. If the build is in the build_posix tree, move there, we have to run in
-# the directory where the format binary lives because the format binary "knows" the wt utility
-# is two directory levels above it.
-[[ -x ${format_binary##* } ]] || {
- build_posix_directory="../../build_posix/test/format"
- [[ ! -d $build_posix_directory ]] || cd $build_posix_directory || exit 1
- [[ -x ${format_binary##* } ]] ||
- fatal_msg "format program \"${format_binary##* }\" not found"
-}
+# Check for the existence of the format_binary. This script is usually copied by CMake into the
+# build directory, in which case we can expect to find the binary in the same directory as
+# format.sh (being the default path value assigned to 'format_bin_dir'). If we can't detect the format
+# binary, raise an error, as we expect the user to either execute the 'format.sh' script under the
+# build directory or by passing the format build directory as an argument.
+[[ -x ${format_binary##* } ]] ||
+ fatal_msg "format program \"${format_binary##* }\" not found"
+
# Find the wt binary (required for abort/recovery testing).
wt_binary="../../wt"
diff --git a/src/third_party/wiredtiger/test/fuzz/Makefile.am b/src/third_party/wiredtiger/test/fuzz/Makefile.am
deleted file mode 100644
index 0d768e17db2..00000000000
--- a/src/third_party/wiredtiger/test/fuzz/Makefile.am
+++ /dev/null
@@ -1,20 +0,0 @@
-AM_CPPFLAGS = -fsanitize=fuzzer-no-link
-AM_CPPFLAGS += -I$(top_builddir)
-AM_CPPFLAGS += -I$(top_srcdir)/src/include
-AM_CPPFLAGS += -I$(top_srcdir)/test/fuzz
-AM_CPPFLAGS += -I$(top_srcdir)/test/utility
-
-AM_LDFLAGS = -fsanitize=fuzzer -static
-
-noinst_LTLIBRARIES = libfuzz_util.la
-noinst_PROGRAMS = fuzz_config fuzz_modify
-
-libfuzz_util_la_SOURCES = fuzz_util.c
-libfuzz_util_la_LIBADD = $(top_builddir)/libwiredtiger.la
-libfuzz_util_la_LIBADD += $(top_builddir)/test/utility/libtest_util.la
-
-fuzz_config_SOURCES = config/fuzz_config.c
-fuzz_config_LDADD = libfuzz_util.la
-
-fuzz_modify_SOURCES = modify/fuzz_modify.c
-fuzz_modify_LDADD = libfuzz_util.la
diff --git a/src/third_party/wiredtiger/test/fuzz/fuzz_run.sh b/src/third_party/wiredtiger/test/fuzz/fuzz_run.sh
index b0958ba1679..86a2b8165ea 100644
--- a/src/third_party/wiredtiger/test/fuzz/fuzz_run.sh
+++ b/src/third_party/wiredtiger/test/fuzz/fuzz_run.sh
@@ -14,7 +14,7 @@
#
# If the fuzzer you're running has an existing corpus directory, you may want to run with the corpus
# supplied:
-# e.g. fuzz_run.sh ../../build_posix/test/fuzz/fuzz_config corpus/
+# e.g. fuzz_run.sh ../../build/test/fuzz/fuzz_config corpus/
#
# Output
# crash-<input-hash> --
diff --git a/src/third_party/wiredtiger/test/huge/Makefile.am b/src/third_party/wiredtiger/test/huge/Makefile.am
deleted file mode 100644
index 402e8efc81e..00000000000
--- a/src/third_party/wiredtiger/test/huge/Makefile.am
+++ /dev/null
@@ -1,16 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = huge.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = smoke.sh
-
-clean-local:
- rm -rf WT_TEST core.* *.core
diff --git a/src/third_party/wiredtiger/test/manydbs/Makefile.am b/src/third_party/wiredtiger/test/manydbs/Makefile.am
deleted file mode 100644
index 66310350d71..00000000000
--- a/src/third_party/wiredtiger/test/manydbs/Makefile.am
+++ /dev/null
@@ -1,17 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = manydbs.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = $(noinst_PROGRAMS)
-LOG_COMPILER = $(TEST_WRAPPER)
-
-clean-local:
- rm -rf WT_TEST core.* *.core
diff --git a/src/third_party/wiredtiger/test/packing/Makefile.am b/src/third_party/wiredtiger/test/packing/Makefile.am
deleted file mode 100644
index 0f6f59d2cff..00000000000
--- a/src/third_party/wiredtiger/test/packing/Makefile.am
+++ /dev/null
@@ -1,14 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = intpack-test intpack-test2 intpack-test3 packing-test
-
-LDADD = $(top_builddir)/test/utility/libtest_util.la
-LDADD +=$(top_builddir)/libwiredtiger.la
-LDFLAGS = -static
-
-TESTS = smoke.sh
-
-clean-local:
- rm -rf core.* *.core
diff --git a/src/third_party/wiredtiger/test/readonly/Makefile.am b/src/third_party/wiredtiger/test/readonly/Makefile.am
deleted file mode 100644
index 7dd08586122..00000000000
--- a/src/third_party/wiredtiger/test/readonly/Makefile.am
+++ /dev/null
@@ -1,16 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = readonly.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = smoke.sh
-
-clean-local:
- rm -rf WT_RD* core.* *.core
diff --git a/src/third_party/wiredtiger/test/salvage/Makefile.am b/src/third_party/wiredtiger/test/salvage/Makefile.am
deleted file mode 100644
index b1540e639ba..00000000000
--- a/src/third_party/wiredtiger/test/salvage/Makefile.am
+++ /dev/null
@@ -1,17 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = salvage.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-# Run this during a "make check" smoke test.
-TESTS = $(noinst_PROGRAMS)
-LOG_COMPILER = $(TEST_WRAPPER)
-
-clean-local:
- rm -rf core.* *.core WT_TEST
diff --git a/src/third_party/wiredtiger/test/suite/run.py b/src/third_party/wiredtiger/test/suite/run.py
index 24baaff822f..1e63fbd14d5 100755
--- a/src/third_party/wiredtiger/test/suite/run.py
+++ b/src/third_party/wiredtiger/test/suite/run.py
@@ -46,27 +46,22 @@ suitedir = sys.path[0]
wt_disttop = os.path.dirname(os.path.dirname(suitedir))
wt_3rdpartydir = os.path.join(wt_disttop, 'test', '3rdparty')
-# Check for a local build that contains the wt utility. First check in
-# current working directory, then in build_posix and finally in the disttop
-# directory. This isn't ideal - if a user has multiple builds in a tree we
+# Check for a local build that contains the wt utility. First check if the
+# supplied an explicit build directory ('WT_BUILDDIR'), then the current
+# working directory, and finally in the disttop directory.
+# This isn't ideal - if a user has multiple builds in a tree we
# could pick the wrong one. We also need to account for the fact that there
-# may be an executable 'wt' file the build directory and a subordinate .libs
-# directory.
+# may be an executable 'wt' file the build directory.
env_builddir = os.getenv('WT_BUILDDIR')
curdir = os.getcwd()
if env_builddir and os.path.isfile(os.path.join(env_builddir, 'wt')):
wt_builddir = env_builddir
-elif os.path.basename(curdir) == '.libs' and \
- os.path.isfile(os.path.join(curdir, os.pardir, 'wt')):
- wt_builddir = os.path.join(curdir, os.pardir)
elif os.path.isfile(os.path.join(curdir, 'wt')):
wt_builddir = curdir
elif os.path.isfile(os.path.join(curdir, 'wt.exe')):
wt_builddir = curdir
elif os.path.isfile(os.path.join(wt_disttop, 'wt')):
wt_builddir = wt_disttop
-elif os.path.isfile(os.path.join(wt_disttop, 'build_posix', 'wt')):
- wt_builddir = os.path.join(wt_disttop, 'build_posix')
elif os.path.isfile(os.path.join(wt_disttop, 'wt.exe')):
wt_builddir = wt_disttop
else:
@@ -108,7 +103,7 @@ unittest = None
def usage():
print('Usage:\n\
- $ cd build_posix\n\
+ $ cd build\n\
$ python ../test/suite/run.py [ options ] [ tests ]\n\
\n\
Options:\n\
diff --git a/src/third_party/wiredtiger/test/syscall/Makefile.am b/src/third_party/wiredtiger/test/syscall/Makefile.am
deleted file mode 100644
index 1d55b06c388..00000000000
--- a/src/third_party/wiredtiger/test/syscall/Makefile.am
+++ /dev/null
@@ -1,7 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir) -I$(top_srcdir)/src/include
-LDADD = $(top_builddir)/libwiredtiger.la
-AM_LDFLAGS = -static
-noinst_PROGRAMS =
-
-test_wt2336_base_SOURCES = wt2336_base/main.c
-noinst_PROGRAMS += test_wt2336_base
diff --git a/src/third_party/wiredtiger/test/syscall/syscall.py b/src/third_party/wiredtiger/test/syscall/syscall.py
index 09f6474fe1f..e88ae67bc05 100755
--- a/src/third_party/wiredtiger/test/syscall/syscall.py
+++ b/src/third_party/wiredtiger/test/syscall/syscall.py
@@ -971,7 +971,7 @@ wt_disttop = os.path.dirname(os.path.dirname(syscalldir))
# Check for a local build that contains the wt utility. First check if the user
# manually specified a local build through the 'WT_BUILDDIR' env variable. Otherwise
# iterate through other possible locations. This including current working directory,
-# then in build_posix and finally in the dist directory. This isn't ideal - if a
+# and in the dist directory. This isn't ideal - if a
# user has multiple builds in a tree we could pick the wrong one.
env_builddir = os.getenv('WT_BUILDDIR')
if env_builddir and os.path.isfile(os.path.join(env_builddir, 'wt')):
@@ -980,8 +980,6 @@ elif os.path.isfile(os.path.join(os.getcwd(), 'wt')):
wt_builddir = os.getcwd()
elif os.path.isfile(os.path.join(wt_disttop, 'wt')):
wt_builddir = wt_disttop
-elif os.path.isfile(os.path.join(wt_disttop, 'build_posix', 'wt')):
- wt_builddir = os.path.join(wt_disttop, 'build_posix')
elif os.path.isfile(os.path.join(wt_disttop, 'wt.exe')):
wt_builddir = wt_disttop
else:
diff --git a/src/third_party/wiredtiger/test/thread/Makefile.am b/src/third_party/wiredtiger/test/thread/Makefile.am
deleted file mode 100644
index 182effa3201..00000000000
--- a/src/third_party/wiredtiger/test/thread/Makefile.am
+++ /dev/null
@@ -1,15 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir)
-AM_CPPFLAGS +=-I$(top_srcdir)/src/include
-AM_CPPFLAGS +=-I$(top_srcdir)/test/utility
-
-noinst_PROGRAMS = t
-t_SOURCES = file.c rw.c stats.c t.c
-
-t_LDADD = $(top_builddir)/test/utility/libtest_util.la
-t_LDADD +=$(top_builddir)/libwiredtiger.la
-t_LDFLAGS = -static
-
-TESTS = smoke.sh
-
-clean-local:
- rm -rf WT_TEST __stats core.* *.core
diff --git a/src/third_party/wiredtiger/test/utility/Makefile.am b/src/third_party/wiredtiger/test/utility/Makefile.am
deleted file mode 100644
index 4bdbc775a59..00000000000
--- a/src/third_party/wiredtiger/test/utility/Makefile.am
+++ /dev/null
@@ -1,4 +0,0 @@
-AM_CPPFLAGS = -I$(top_builddir) -I$(top_srcdir)/src/include
-
-libtest_util_la_SOURCES = misc.c modify.c parse_opts.c thread.c
-noinst_LTLIBRARIES = libtest_util.la
diff --git a/src/third_party/wiredtiger/test/utility/misc.c b/src/third_party/wiredtiger/test/utility/misc.c
index 5430af02857..f61a429fafd 100644
--- a/src/third_party/wiredtiger/test/utility/misc.c
+++ b/src/third_party/wiredtiger/test/utility/misc.c
@@ -140,42 +140,21 @@ testutil_clean_work_dir(const char *dir)
/*
* testutil_build_dir --
- * Get the git top level directory and concatenate the build directory.
+ * Get the build directory.
*/
void
testutil_build_dir(TEST_OPTS *opts, char *buf, int size)
{
- FILE *fp;
- char *p;
-
- /* If a build directory was manually given as an option we can directly return this instead. */
- if (opts->build_dir != NULL) {
- strncpy(buf, opts->build_dir, (size_t)size);
- return;
- }
-
- /* Get the git top level directory. */
-#ifdef _WIN32
- fp = _popen("git rev-parse --show-toplevel", "r");
-#else
- fp = popen("git rev-parse --show-toplevel", "r");
-#endif
-
- if (fp == NULL)
- testutil_die(errno, "popen");
- p = fgets(buf, size, fp);
- if (p == NULL)
- testutil_die(errno, "fgets");
-
-#ifdef _WIN32
- _pclose(fp);
-#else
- pclose(fp);
-#endif
+ /* To keep it simple, in order to get the build directory we require the user to set the build
+ * directory from the command line options.
+ * We unfortunately can't depend on a known/constant build directory (the user could have
+ * multiple out-of-source build directories). There's also not really any OS-agnostic mechanisms
+ * we can here use to discover the build directory the calling test binary exists in.
+ */
+ if (opts->build_dir == NULL)
+ testutil_die(ENOENT, "No build directory given");
- /* Remove the trailing newline character added by fgets. */
- buf[strlen(buf) - 1] = '\0';
- strcat(buf, "/build_posix");
+ strncpy(buf, opts->build_dir, (size_t)size);
}
/*
diff --git a/src/third_party/wiredtiger/test/wtperf/test_conf_dump.py b/src/third_party/wiredtiger/test/wtperf/test_conf_dump.py
index 6e9faf65b6b..bc2147202f8 100755
--- a/src/third_party/wiredtiger/test/wtperf/test_conf_dump.py
+++ b/src/third_party/wiredtiger/test/wtperf/test_conf_dump.py
@@ -26,7 +26,7 @@
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
-# Usage: python test_conf_dump.py <optional-wtperf-config>
+# Usage: python test_conf_dump.py -d wtperf_directory [-c optional_wtperf_config]
#
# This script tests if the config file dumped in the test directory corresponds
# correctly to the wtperf config file used. Command line options to wtperf are
@@ -46,18 +46,19 @@
# fails if the value for the option is not replaced/appended in the correct
# order of precedence as stated above.
-import os, re, subprocess, sys
+import os, re, subprocess
+import argparse
OP_FILE = "WT_TEST/CONFIG.wtperf"
TMP_CONF = "__tmp.wtperf"
WTPERF_BIN = "./wtperf"
-env_wtperfdir = os.getenv('WTPERF_DIR')
-if env_wtperfdir:
- WTPERF_DIR = env_wtperfdir
-else:
- WTPERF_DIR = "../../build_posix/bench/wtperf/"
+ap = argparse.ArgumentParser('Validates a WiredTiger test config files matches the wtperf config file being used')
+ap.add_argument('-d', '--wtperf_dir', type=str, required=True, help="Specify the wtperf binary directory")
+ap.add_argument('-c', '--config', help="Optional wtperf config file")
+args = ap.parse_args()
+WTPERF_DIR = args.wtperf_dir
CONF_NOT_PROVIDED = -2
# Generate a wtperf conf file to use
@@ -304,8 +305,8 @@ def run_test(conf_file, option_C = "", option_T = "", option_o = ""):
# ----------------- Execute Test --------------
# If a wtperf conf file is provided use it, else generate a temp conf file
os.chdir(WTPERF_DIR)
-if len(sys.argv) == 2:
- conf_file = sys.argv[1]
+if args.config:
+ conf_file = args.config
else:
conf_file = TMP_CONF
generate_conf_file(conf_file)
@@ -323,7 +324,7 @@ if not run_test(conf_file, option_C, option_T, option_o):
# Cleanup generated temp files
subprocess.check_call("rm -rf WT_TEST/", shell=True)
-if len(sys.argv) == 1 and conf_file == TMP_CONF:
+if not args.config and conf_file == TMP_CONF:
subprocess.check_call("rm " + TMP_CONF, shell=True)
print("All tests succeeded")
diff --git a/src/third_party/wiredtiger/test/evergreen/evg_cfg.py b/src/third_party/wiredtiger/test/evergreen/evg_cfg.py
index e966ce0d69e..7fc4eea5530 100755
--- a/src/third_party/wiredtiger/test/evergreen/evg_cfg.py
+++ b/src/third_party/wiredtiger/test/evergreen/evg_cfg.py
@@ -30,7 +30,10 @@ CSUITE_TEST_SEARCH_STR = " # End of csuite test tasks"
# They are not expected to trigger any 'make check' testing.
make_check_subdir_skips = [
"test/csuite", # csuite has its own set of Evergreen tasks, skip the checking here
- "test/cppsuite"
+ "test/cppsuite",
+ "test/fuzz",
+ "test/syscall",
+ "ext/storage_sources/s3_store/test"
]
prog=sys.argv[0]
@@ -132,22 +135,23 @@ def find_tests_missing_evg_cfg(test_type, dirs, evg_cfg_file):
def get_make_check_dirs():
"""
Figure out the 'make check' directories that are applicable for testing
- Directories with Makefile.am containing 'TESTS =' are the ones require test.
+ Directories with CMakeLists.txt containing ctest declaration ('add_test',
+ 'define_c_test', 'define_test_variants') are the ones require test.
Skip a few known directories that do not require test or covered separately.
"""
# Make sure we are under the repo top level directory
os.chdir(run('git rev-parse --show-toplevel'))
# Search keyword in Makefile.am to identify directories that involve test configuration.
# Need to use subprocess 'shell=True' to get the expected shell command output.
- cmd = "find . -name Makefile.am -exec grep -H -e '^TESTS =' {} \; | cut -d: -f1 | cut -c3-"
+ cmd = "find . -name CMakeLists.txt -exec grep -H -e '\(add_test\|define_c_test|define_test_variants\)' {} \; | cut -d: -f1 | cut -c3- | uniq"
p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
mkfiles_with_tests = p.stdout.readlines()
# Need some string manipulation work here against the subprocess output.
# Cast elements to string, and strip the ending from the string to get directory names.
- ending = '/Makefile.am\n'
+ ending = '/CMakeLists.txt\n'
dirs_with_tests = [d.decode('utf-8')[:-len(ending)] for d in mkfiles_with_tests]
debug("dirs_with_tests: %s" % dirs_with_tests)
@@ -132,22 +135,23 @@ def find_tests_missing_evg_cfg(test_type, dirs, evg_cfg_file):
# Make sure we are under the repo top level directory
os.chdir(run('git rev-parse --show-toplevel'))
- # Search keyword in Makefile.am to identify directories that involve test configuration.
+ # Search keyword in CMakeLists.txt to identify directories that involve test configuration.
# Need to use subprocess 'shell=True' to get the expected shell command output.